tempotools.report_integer_tempo_rewrite_pairs
=============================================

.. autofunction:: abjad.tools.tempotools.report_integer_tempo_rewrite_pairs.report_integer_tempo_rewrite_pairs
   :noindex:
